scripts

package
v0.3.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package scripts embeds all built-in JS node scripts via embed.FS.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuiltinTypes

func BuiltinTypes() []string

BuiltinTypes returns the list of all built-in JS node type names, derived automatically from the embedded .js files.

func Get

func Get(nodeType string) (string, error)

Get returns the JS source for a built-in node type.

func IsBuiltin

func IsBuiltin(nodeType string) bool

IsBuiltin reports whether the given node type has a built-in JS script.

func MustGet

func MustGet(nodeType string) string

MustGet is like Get but panics on error.

Types

This section is empty.

Jump to