Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterNodeServiceServer(s grpc.ServiceRegistrar, srv NodeServiceServer)
- func RegisterPluginLifecycleServer(s grpc.ServiceRegistrar, srv PluginLifecycleServer)
- func RegisterToolServiceServer(s grpc.ServiceRegistrar, srv ToolServiceServer)
- type GetVarRequest
- type GetVarResponse
- func (*GetVarResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetVarResponse) GetFound() bool
- func (x *GetVarResponse) GetValue() string
- func (*GetVarResponse) ProtoMessage()
- func (x *GetVarResponse) ProtoReflect() protoreflect.Message
- func (x *GetVarResponse) Reset()
- func (x *GetVarResponse) String() string
- type HandshakeRequest
- func (*HandshakeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *HandshakeRequest) GetHostVersion() string
- func (x *HandshakeRequest) GetProtocolVersion() int32
- func (*HandshakeRequest) ProtoMessage()
- func (x *HandshakeRequest) ProtoReflect() protoreflect.Message
- func (x *HandshakeRequest) Reset()
- func (x *HandshakeRequest) String() string
- type HandshakeResponse
- func (*HandshakeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *HandshakeResponse) GetNodes() []*NodeSpec
- func (x *HandshakeResponse) GetPluginInfo() *PluginInfo
- func (x *HandshakeResponse) GetProtocolVersion() int32
- func (x *HandshakeResponse) GetTools() []*ToolSpec
- func (*HandshakeResponse) ProtoMessage()
- func (x *HandshakeResponse) ProtoReflect() protoreflect.Message
- func (x *HandshakeResponse) Reset()
- func (x *HandshakeResponse) String() string
- type HealthCheckRequest
- type HealthCheckResponse
- func (*HealthCheckResponse) Descriptor() ([]byte, []int)deprecated
- func (x *HealthCheckResponse) GetHealthy() bool
- func (*HealthCheckResponse) ProtoMessage()
- func (x *HealthCheckResponse) ProtoReflect() protoreflect.Message
- func (x *HealthCheckResponse) Reset()
- func (x *HealthCheckResponse) String() string
- type InitializeRequest
- func (*InitializeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *InitializeRequest) GetConfig() map[string]string
- func (*InitializeRequest) ProtoMessage()
- func (x *InitializeRequest) ProtoReflect() protoreflect.Message
- func (x *InitializeRequest) Reset()
- func (x *InitializeRequest) String() string
- type InitializeResponse
- type LLMGenerateRequest
- func (*LLMGenerateRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LLMGenerateRequest) GetPrompt() string
- func (*LLMGenerateRequest) ProtoMessage()
- func (x *LLMGenerateRequest) ProtoReflect() protoreflect.Message
- func (x *LLMGenerateRequest) Reset()
- func (x *LLMGenerateRequest) String() string
- type LLMGenerateResponse
- func (*LLMGenerateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *LLMGenerateResponse) GetError() string
- func (x *LLMGenerateResponse) GetResult() string
- func (*LLMGenerateResponse) ProtoMessage()
- func (x *LLMGenerateResponse) ProtoReflect() protoreflect.Message
- func (x *LLMGenerateResponse) Reset()
- func (x *LLMGenerateResponse) String() string
- type ListNodesRequest
- type ListNodesResponse
- func (*ListNodesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListNodesResponse) GetNodes() []*NodeSpec
- func (*ListNodesResponse) ProtoMessage()
- func (x *ListNodesResponse) ProtoReflect() protoreflect.Message
- func (x *ListNodesResponse) Reset()
- func (x *ListNodesResponse) String() string
- type ListToolsRequest
- type ListToolsResponse
- func (*ListToolsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListToolsResponse) GetTools() []*ToolSpec
- func (*ListToolsResponse) ProtoMessage()
- func (x *ListToolsResponse) ProtoReflect() protoreflect.Message
- func (x *ListToolsResponse) Reset()
- func (x *ListToolsResponse) String() string
- type NodeExecuteRequest
- func (*NodeExecuteRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NodeExecuteRequest) GetConfig() map[string]string
- func (x *NodeExecuteRequest) GetNodeId() string
- func (*NodeExecuteRequest) ProtoMessage()
- func (x *NodeExecuteRequest) ProtoReflect() protoreflect.Message
- func (x *NodeExecuteRequest) Reset()
- func (x *NodeExecuteRequest) String() string
- type NodeExecuteResponse
- func (*NodeExecuteResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NodeExecuteResponse) GetError() string
- func (x *NodeExecuteResponse) GetOutputs() map[string]string
- func (*NodeExecuteResponse) ProtoMessage()
- func (x *NodeExecuteResponse) ProtoReflect() protoreflect.Message
- func (x *NodeExecuteResponse) Reset()
- func (x *NodeExecuteResponse) String() string
- type NodeMessage
- func (*NodeMessage) Descriptor() ([]byte, []int)deprecated
- func (x *NodeMessage) GetExecuteRequest() *NodeExecuteRequest
- func (x *NodeMessage) GetExecuteResponse() *NodeExecuteResponse
- func (x *NodeMessage) GetGetVarRequest() *GetVarRequest
- func (x *NodeMessage) GetGetVarResponse() *GetVarResponse
- func (x *NodeMessage) GetLlmGenerateRequest() *LLMGenerateRequest
- func (x *NodeMessage) GetLlmGenerateResponse() *LLMGenerateResponse
- func (x *NodeMessage) GetMsg() isNodeMessage_Msg
- func (x *NodeMessage) GetSandboxExecRequest() *SandboxExecRequest
- func (x *NodeMessage) GetSandboxExecResponse() *SandboxExecResponse
- func (x *NodeMessage) GetSetVarRequest() *SetVarRequest
- func (x *NodeMessage) GetSignalRequest() *SignalRequest
- func (x *NodeMessage) GetSignalResponse() *SignalResponse
- func (x *NodeMessage) GetStreamEmitRequest() *StreamEmitRequest
- func (x *NodeMessage) GetToolExecuteRequest() *ToolExecuteRequest
- func (x *NodeMessage) GetToolExecuteResponse() *ToolExecuteResponse
- func (*NodeMessage) ProtoMessage()
- func (x *NodeMessage) ProtoReflect() protoreflect.Message
- func (x *NodeMessage) Reset()
- func (x *NodeMessage) String() string
- type NodeMessage_ExecuteRequest
- type NodeMessage_ExecuteResponse
- type NodeMessage_GetVarRequest
- type NodeMessage_GetVarResponse
- type NodeMessage_LlmGenerateRequest
- type NodeMessage_LlmGenerateResponse
- type NodeMessage_SandboxExecRequest
- type NodeMessage_SandboxExecResponse
- type NodeMessage_SetVarRequest
- type NodeMessage_SignalRequest
- type NodeMessage_SignalResponse
- type NodeMessage_StreamEmitRequest
- type NodeMessage_ToolExecuteRequest
- type NodeMessage_ToolExecuteResponse
- type NodeServiceClient
- type NodeServiceServer
- type NodeService_ExecuteClient
- type NodeService_ExecuteServer
- type NodeSpec
- type PluginInfo
- func (*PluginInfo) Descriptor() ([]byte, []int)deprecated
- func (x *PluginInfo) GetAuthor() string
- func (x *PluginInfo) GetBuiltin() bool
- func (x *PluginInfo) GetDescription() string
- func (x *PluginInfo) GetId() string
- func (x *PluginInfo) GetName() string
- func (x *PluginInfo) GetType() string
- func (x *PluginInfo) GetVersion() string
- func (*PluginInfo) ProtoMessage()
- func (x *PluginInfo) ProtoReflect() protoreflect.Message
- func (x *PluginInfo) Reset()
- func (x *PluginInfo) String() string
- type PluginLifecycleClient
- type PluginLifecycleServer
- type SandboxExecRequest
- func (*SandboxExecRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SandboxExecRequest) GetCommand() string
- func (*SandboxExecRequest) ProtoMessage()
- func (x *SandboxExecRequest) ProtoReflect() protoreflect.Message
- func (x *SandboxExecRequest) Reset()
- func (x *SandboxExecRequest) String() string
- type SandboxExecResponse
- func (*SandboxExecResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SandboxExecResponse) GetError() string
- func (x *SandboxExecResponse) GetOutput() string
- func (*SandboxExecResponse) ProtoMessage()
- func (x *SandboxExecResponse) ProtoReflect() protoreflect.Message
- func (x *SandboxExecResponse) Reset()
- func (x *SandboxExecResponse) String() string
- type SetVarRequest
- func (*SetVarRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetVarRequest) GetKey() string
- func (x *SetVarRequest) GetValue() string
- func (*SetVarRequest) ProtoMessage()
- func (x *SetVarRequest) ProtoReflect() protoreflect.Message
- func (x *SetVarRequest) Reset()
- func (x *SetVarRequest) String() string
- type ShutdownRequest
- type ShutdownResponse
- type SignalRequest
- func (*SignalRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SignalRequest) GetPayload() []byte
- func (x *SignalRequest) GetSignalType() string
- func (*SignalRequest) ProtoMessage()
- func (x *SignalRequest) ProtoReflect() protoreflect.Message
- func (x *SignalRequest) Reset()
- func (x *SignalRequest) String() string
- type SignalResponse
- type StreamEmitRequest
- type ToolExecuteRequest
- func (*ToolExecuteRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ToolExecuteRequest) GetArguments() string
- func (x *ToolExecuteRequest) GetName() string
- func (*ToolExecuteRequest) ProtoMessage()
- func (x *ToolExecuteRequest) ProtoReflect() protoreflect.Message
- func (x *ToolExecuteRequest) Reset()
- func (x *ToolExecuteRequest) String() string
- type ToolExecuteResponse
- func (*ToolExecuteResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ToolExecuteResponse) GetError() string
- func (x *ToolExecuteResponse) GetResult() string
- func (*ToolExecuteResponse) ProtoMessage()
- func (x *ToolExecuteResponse) ProtoReflect() protoreflect.Message
- func (x *ToolExecuteResponse) Reset()
- func (x *ToolExecuteResponse) String() string
- type ToolServiceClient
- type ToolServiceServer
- type ToolSpec
- func (*ToolSpec) Descriptor() ([]byte, []int)deprecated
- func (x *ToolSpec) GetDescription() string
- func (x *ToolSpec) GetInputSchemaJson() string
- func (x *ToolSpec) GetName() string
- func (*ToolSpec) ProtoMessage()
- func (x *ToolSpec) ProtoReflect() protoreflect.Message
- func (x *ToolSpec) Reset()
- func (x *ToolSpec) String() string
- type UnimplementedNodeServiceServer
- type UnimplementedPluginLifecycleServer
- func (UnimplementedPluginLifecycleServer) Handshake(context.Context, *HandshakeRequest) (*HandshakeResponse, error)
- func (UnimplementedPluginLifecycleServer) HealthCheck(context.Context, *HealthCheckRequest) (*HealthCheckResponse, error)
- func (UnimplementedPluginLifecycleServer) Initialize(context.Context, *InitializeRequest) (*InitializeResponse, error)
- func (UnimplementedPluginLifecycleServer) Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
- type UnimplementedToolServiceServer
- type UnsafeNodeServiceServer
- type UnsafePluginLifecycleServer
- type UnsafeToolServiceServer
Constants ¶
const ( PluginLifecycle_Handshake_FullMethodName = "/plugin.PluginLifecycle/Handshake" PluginLifecycle_Initialize_FullMethodName = "/plugin.PluginLifecycle/Initialize" PluginLifecycle_Shutdown_FullMethodName = "/plugin.PluginLifecycle/Shutdown" PluginLifecycle_HealthCheck_FullMethodName = "/plugin.PluginLifecycle/HealthCheck" )
const ( ToolService_ListTools_FullMethodName = "/plugin.ToolService/ListTools" ToolService_Execute_FullMethodName = "/plugin.ToolService/Execute" )
const ( NodeService_ListNodes_FullMethodName = "/plugin.NodeService/ListNodes" NodeService_Execute_FullMethodName = "/plugin.NodeService/Execute" )
Variables ¶
var File_proto_plugin_proto protoreflect.FileDescriptor
var NodeService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.NodeService", HandlerType: (*NodeServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListNodes", Handler: _NodeService_ListNodes_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Execute", Handler: _NodeService_Execute_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "proto/plugin.proto", }
NodeService_ServiceDesc is the grpc.ServiceDesc for NodeService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var PluginLifecycle_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.PluginLifecycle", HandlerType: (*PluginLifecycleServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Handshake", Handler: _PluginLifecycle_Handshake_Handler, }, { MethodName: "Initialize", Handler: _PluginLifecycle_Initialize_Handler, }, { MethodName: "Shutdown", Handler: _PluginLifecycle_Shutdown_Handler, }, { MethodName: "HealthCheck", Handler: _PluginLifecycle_HealthCheck_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin.proto", }
PluginLifecycle_ServiceDesc is the grpc.ServiceDesc for PluginLifecycle service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ToolService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.ToolService", HandlerType: (*ToolServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListTools", Handler: _ToolService_ListTools_Handler, }, { MethodName: "Execute", Handler: _ToolService_Execute_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin.proto", }
ToolService_ServiceDesc is the grpc.ServiceDesc for ToolService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterNodeServiceServer ¶
func RegisterNodeServiceServer(s grpc.ServiceRegistrar, srv NodeServiceServer)
func RegisterPluginLifecycleServer ¶
func RegisterPluginLifecycleServer(s grpc.ServiceRegistrar, srv PluginLifecycleServer)
func RegisterToolServiceServer ¶
func RegisterToolServiceServer(s grpc.ServiceRegistrar, srv ToolServiceServer)
Types ¶
type GetVarRequest ¶
type GetVarRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*GetVarRequest) Descriptor
deprecated
func (*GetVarRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetVarRequest.ProtoReflect.Descriptor instead.
func (*GetVarRequest) GetKey ¶
func (x *GetVarRequest) GetKey() string
func (*GetVarRequest) ProtoMessage ¶
func (*GetVarRequest) ProtoMessage()
func (*GetVarRequest) ProtoReflect ¶
func (x *GetVarRequest) ProtoReflect() protoreflect.Message
func (*GetVarRequest) Reset ¶
func (x *GetVarRequest) Reset()
func (*GetVarRequest) String ¶
func (x *GetVarRequest) String() string
type GetVarResponse ¶
type GetVarResponse struct {
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
Found bool `protobuf:"varint,2,opt,name=found,proto3" json:"found,omitempty"`
// contains filtered or unexported fields
}
func (*GetVarResponse) Descriptor
deprecated
func (*GetVarResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetVarResponse.ProtoReflect.Descriptor instead.
func (*GetVarResponse) GetFound ¶
func (x *GetVarResponse) GetFound() bool
func (*GetVarResponse) GetValue ¶
func (x *GetVarResponse) GetValue() string
func (*GetVarResponse) ProtoMessage ¶
func (*GetVarResponse) ProtoMessage()
func (*GetVarResponse) ProtoReflect ¶
func (x *GetVarResponse) ProtoReflect() protoreflect.Message
func (*GetVarResponse) Reset ¶
func (x *GetVarResponse) Reset()
func (*GetVarResponse) String ¶
func (x *GetVarResponse) String() string
type HandshakeRequest ¶
type HandshakeRequest struct {
HostVersion string `protobuf:"bytes,1,opt,name=host_version,json=hostVersion,proto3" json:"host_version,omitempty"`
ProtocolVersion int32 `protobuf:"varint,2,opt,name=protocol_version,json=protocolVersion,proto3" json:"protocol_version,omitempty"`
// contains filtered or unexported fields
}
func (*HandshakeRequest) Descriptor
deprecated
func (*HandshakeRequest) Descriptor() ([]byte, []int)
Deprecated: Use HandshakeRequest.ProtoReflect.Descriptor instead.
func (*HandshakeRequest) GetHostVersion ¶
func (x *HandshakeRequest) GetHostVersion() string
func (*HandshakeRequest) GetProtocolVersion ¶
func (x *HandshakeRequest) GetProtocolVersion() int32
func (*HandshakeRequest) ProtoMessage ¶
func (*HandshakeRequest) ProtoMessage()
func (*HandshakeRequest) ProtoReflect ¶
func (x *HandshakeRequest) ProtoReflect() protoreflect.Message
func (*HandshakeRequest) Reset ¶
func (x *HandshakeRequest) Reset()
func (*HandshakeRequest) String ¶
func (x *HandshakeRequest) String() string
type HandshakeResponse ¶
type HandshakeResponse struct {
PluginInfo *PluginInfo `protobuf:"bytes,1,opt,name=plugin_info,json=pluginInfo,proto3" json:"plugin_info,omitempty"`
ProtocolVersion int32 `protobuf:"varint,2,opt,name=protocol_version,json=protocolVersion,proto3" json:"protocol_version,omitempty"`
Tools []*ToolSpec `protobuf:"bytes,3,rep,name=tools,proto3" json:"tools,omitempty"`
Nodes []*NodeSpec `protobuf:"bytes,4,rep,name=nodes,proto3" json:"nodes,omitempty"`
// contains filtered or unexported fields
}
func (*HandshakeResponse) Descriptor
deprecated
func (*HandshakeResponse) Descriptor() ([]byte, []int)
Deprecated: Use HandshakeResponse.ProtoReflect.Descriptor instead.
func (*HandshakeResponse) GetNodes ¶
func (x *HandshakeResponse) GetNodes() []*NodeSpec
func (*HandshakeResponse) GetPluginInfo ¶
func (x *HandshakeResponse) GetPluginInfo() *PluginInfo
func (*HandshakeResponse) GetProtocolVersion ¶
func (x *HandshakeResponse) GetProtocolVersion() int32
func (*HandshakeResponse) GetTools ¶
func (x *HandshakeResponse) GetTools() []*ToolSpec
func (*HandshakeResponse) ProtoMessage ¶
func (*HandshakeResponse) ProtoMessage()
func (*HandshakeResponse) ProtoReflect ¶
func (x *HandshakeResponse) ProtoReflect() protoreflect.Message
func (*HandshakeResponse) Reset ¶
func (x *HandshakeResponse) Reset()
func (*HandshakeResponse) String ¶
func (x *HandshakeResponse) String() string
type HealthCheckRequest ¶
type HealthCheckRequest struct {
// contains filtered or unexported fields
}
func (*HealthCheckRequest) Descriptor
deprecated
func (*HealthCheckRequest) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheckRequest.ProtoReflect.Descriptor instead.
func (*HealthCheckRequest) ProtoMessage ¶
func (*HealthCheckRequest) ProtoMessage()
func (*HealthCheckRequest) ProtoReflect ¶
func (x *HealthCheckRequest) ProtoReflect() protoreflect.Message
func (*HealthCheckRequest) Reset ¶
func (x *HealthCheckRequest) Reset()
func (*HealthCheckRequest) String ¶
func (x *HealthCheckRequest) String() string
type HealthCheckResponse ¶
type HealthCheckResponse struct {
Healthy bool `protobuf:"varint,1,opt,name=healthy,proto3" json:"healthy,omitempty"`
// contains filtered or unexported fields
}
func (*HealthCheckResponse) Descriptor
deprecated
func (*HealthCheckResponse) Descriptor() ([]byte, []int)
Deprecated: Use HealthCheckResponse.ProtoReflect.Descriptor instead.
func (*HealthCheckResponse) GetHealthy ¶
func (x *HealthCheckResponse) GetHealthy() bool
func (*HealthCheckResponse) ProtoMessage ¶
func (*HealthCheckResponse) ProtoMessage()
func (*HealthCheckResponse) ProtoReflect ¶
func (x *HealthCheckResponse) ProtoReflect() protoreflect.Message
func (*HealthCheckResponse) Reset ¶
func (x *HealthCheckResponse) Reset()
func (*HealthCheckResponse) String ¶
func (x *HealthCheckResponse) String() string
type InitializeRequest ¶
type InitializeRequest struct {
Config map[string]string `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*InitializeRequest) Descriptor
deprecated
func (*InitializeRequest) Descriptor() ([]byte, []int)
Deprecated: Use InitializeRequest.ProtoReflect.Descriptor instead.
func (*InitializeRequest) GetConfig ¶
func (x *InitializeRequest) GetConfig() map[string]string
func (*InitializeRequest) ProtoMessage ¶
func (*InitializeRequest) ProtoMessage()
func (*InitializeRequest) ProtoReflect ¶
func (x *InitializeRequest) ProtoReflect() protoreflect.Message
func (*InitializeRequest) Reset ¶
func (x *InitializeRequest) Reset()
func (*InitializeRequest) String ¶
func (x *InitializeRequest) String() string
type InitializeResponse ¶
type InitializeResponse struct {
// contains filtered or unexported fields
}
func (*InitializeResponse) Descriptor
deprecated
func (*InitializeResponse) Descriptor() ([]byte, []int)
Deprecated: Use InitializeResponse.ProtoReflect.Descriptor instead.
func (*InitializeResponse) ProtoMessage ¶
func (*InitializeResponse) ProtoMessage()
func (*InitializeResponse) ProtoReflect ¶
func (x *InitializeResponse) ProtoReflect() protoreflect.Message
func (*InitializeResponse) Reset ¶
func (x *InitializeResponse) Reset()
func (*InitializeResponse) String ¶
func (x *InitializeResponse) String() string
type LLMGenerateRequest ¶
type LLMGenerateRequest struct {
Prompt string `protobuf:"bytes,1,opt,name=prompt,proto3" json:"prompt,omitempty"`
// contains filtered or unexported fields
}
func (*LLMGenerateRequest) Descriptor
deprecated
func (*LLMGenerateRequest) Descriptor() ([]byte, []int)
Deprecated: Use LLMGenerateRequest.ProtoReflect.Descriptor instead.
func (*LLMGenerateRequest) GetPrompt ¶
func (x *LLMGenerateRequest) GetPrompt() string
func (*LLMGenerateRequest) ProtoMessage ¶
func (*LLMGenerateRequest) ProtoMessage()
func (*LLMGenerateRequest) ProtoReflect ¶
func (x *LLMGenerateRequest) ProtoReflect() protoreflect.Message
func (*LLMGenerateRequest) Reset ¶
func (x *LLMGenerateRequest) Reset()
func (*LLMGenerateRequest) String ¶
func (x *LLMGenerateRequest) String() string
type LLMGenerateResponse ¶
type LLMGenerateResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*LLMGenerateResponse) Descriptor
deprecated
func (*LLMGenerateResponse) Descriptor() ([]byte, []int)
Deprecated: Use LLMGenerateResponse.ProtoReflect.Descriptor instead.
func (*LLMGenerateResponse) GetError ¶
func (x *LLMGenerateResponse) GetError() string
func (*LLMGenerateResponse) GetResult ¶
func (x *LLMGenerateResponse) GetResult() string
func (*LLMGenerateResponse) ProtoMessage ¶
func (*LLMGenerateResponse) ProtoMessage()
func (*LLMGenerateResponse) ProtoReflect ¶
func (x *LLMGenerateResponse) ProtoReflect() protoreflect.Message
func (*LLMGenerateResponse) Reset ¶
func (x *LLMGenerateResponse) Reset()
func (*LLMGenerateResponse) String ¶
func (x *LLMGenerateResponse) String() string
type ListNodesRequest ¶
type ListNodesRequest struct {
// contains filtered or unexported fields
}
func (*ListNodesRequest) Descriptor
deprecated
func (*ListNodesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListNodesRequest.ProtoReflect.Descriptor instead.
func (*ListNodesRequest) ProtoMessage ¶
func (*ListNodesRequest) ProtoMessage()
func (*ListNodesRequest) ProtoReflect ¶
func (x *ListNodesRequest) ProtoReflect() protoreflect.Message
func (*ListNodesRequest) Reset ¶
func (x *ListNodesRequest) Reset()
func (*ListNodesRequest) String ¶
func (x *ListNodesRequest) String() string
type ListNodesResponse ¶
type ListNodesResponse struct {
Nodes []*NodeSpec `protobuf:"bytes,1,rep,name=nodes,proto3" json:"nodes,omitempty"`
// contains filtered or unexported fields
}
func (*ListNodesResponse) Descriptor
deprecated
func (*ListNodesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListNodesResponse.ProtoReflect.Descriptor instead.
func (*ListNodesResponse) GetNodes ¶
func (x *ListNodesResponse) GetNodes() []*NodeSpec
func (*ListNodesResponse) ProtoMessage ¶
func (*ListNodesResponse) ProtoMessage()
func (*ListNodesResponse) ProtoReflect ¶
func (x *ListNodesResponse) ProtoReflect() protoreflect.Message
func (*ListNodesResponse) Reset ¶
func (x *ListNodesResponse) Reset()
func (*ListNodesResponse) String ¶
func (x *ListNodesResponse) String() string
type ListToolsRequest ¶
type ListToolsRequest struct {
// contains filtered or unexported fields
}
func (*ListToolsRequest) Descriptor
deprecated
func (*ListToolsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListToolsRequest.ProtoReflect.Descriptor instead.
func (*ListToolsRequest) ProtoMessage ¶
func (*ListToolsRequest) ProtoMessage()
func (*ListToolsRequest) ProtoReflect ¶
func (x *ListToolsRequest) ProtoReflect() protoreflect.Message
func (*ListToolsRequest) Reset ¶
func (x *ListToolsRequest) Reset()
func (*ListToolsRequest) String ¶
func (x *ListToolsRequest) String() string
type ListToolsResponse ¶
type ListToolsResponse struct {
Tools []*ToolSpec `protobuf:"bytes,1,rep,name=tools,proto3" json:"tools,omitempty"`
// contains filtered or unexported fields
}
func (*ListToolsResponse) Descriptor
deprecated
func (*ListToolsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListToolsResponse.ProtoReflect.Descriptor instead.
func (*ListToolsResponse) GetTools ¶
func (x *ListToolsResponse) GetTools() []*ToolSpec
func (*ListToolsResponse) ProtoMessage ¶
func (*ListToolsResponse) ProtoMessage()
func (*ListToolsResponse) ProtoReflect ¶
func (x *ListToolsResponse) ProtoReflect() protoreflect.Message
func (*ListToolsResponse) Reset ¶
func (x *ListToolsResponse) Reset()
func (*ListToolsResponse) String ¶
func (x *ListToolsResponse) String() string
type NodeExecuteRequest ¶
type NodeExecuteRequest struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
Config map[string]string `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*NodeExecuteRequest) Descriptor
deprecated
func (*NodeExecuteRequest) Descriptor() ([]byte, []int)
Deprecated: Use NodeExecuteRequest.ProtoReflect.Descriptor instead.
func (*NodeExecuteRequest) GetConfig ¶
func (x *NodeExecuteRequest) GetConfig() map[string]string
func (*NodeExecuteRequest) GetNodeId ¶
func (x *NodeExecuteRequest) GetNodeId() string
func (*NodeExecuteRequest) ProtoMessage ¶
func (*NodeExecuteRequest) ProtoMessage()
func (*NodeExecuteRequest) ProtoReflect ¶
func (x *NodeExecuteRequest) ProtoReflect() protoreflect.Message
func (*NodeExecuteRequest) Reset ¶
func (x *NodeExecuteRequest) Reset()
func (*NodeExecuteRequest) String ¶
func (x *NodeExecuteRequest) String() string
type NodeExecuteResponse ¶
type NodeExecuteResponse struct {
Outputs map[string]string `` /* 141-byte string literal not displayed */
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*NodeExecuteResponse) Descriptor
deprecated
func (*NodeExecuteResponse) Descriptor() ([]byte, []int)
Deprecated: Use NodeExecuteResponse.ProtoReflect.Descriptor instead.
func (*NodeExecuteResponse) GetError ¶
func (x *NodeExecuteResponse) GetError() string
func (*NodeExecuteResponse) GetOutputs ¶
func (x *NodeExecuteResponse) GetOutputs() map[string]string
func (*NodeExecuteResponse) ProtoMessage ¶
func (*NodeExecuteResponse) ProtoMessage()
func (*NodeExecuteResponse) ProtoReflect ¶
func (x *NodeExecuteResponse) ProtoReflect() protoreflect.Message
func (*NodeExecuteResponse) Reset ¶
func (x *NodeExecuteResponse) Reset()
func (*NodeExecuteResponse) String ¶
func (x *NodeExecuteResponse) String() string
type NodeMessage ¶
type NodeMessage struct {
// Types that are valid to be assigned to Msg:
//
// *NodeMessage_ExecuteRequest
// *NodeMessage_ExecuteResponse
// *NodeMessage_GetVarRequest
// *NodeMessage_GetVarResponse
// *NodeMessage_SetVarRequest
// *NodeMessage_LlmGenerateRequest
// *NodeMessage_LlmGenerateResponse
// *NodeMessage_ToolExecuteRequest
// *NodeMessage_ToolExecuteResponse
// *NodeMessage_StreamEmitRequest
// *NodeMessage_SandboxExecRequest
// *NodeMessage_SandboxExecResponse
// *NodeMessage_SignalRequest
// *NodeMessage_SignalResponse
Msg isNodeMessage_Msg `protobuf_oneof:"msg"`
// contains filtered or unexported fields
}
NodeMessage is the bidirectional streaming message for node execution. The host sends ExecuteRequest, the plugin may send callbacks (GetVar, SetVar, LLMGenerate, ToolExecute, StreamEmit, SandboxExec, Signal), and finally the plugin sends ExecuteResponse.
func (*NodeMessage) Descriptor
deprecated
func (*NodeMessage) Descriptor() ([]byte, []int)
Deprecated: Use NodeMessage.ProtoReflect.Descriptor instead.
func (*NodeMessage) GetExecuteRequest ¶
func (x *NodeMessage) GetExecuteRequest() *NodeExecuteRequest
func (*NodeMessage) GetExecuteResponse ¶
func (x *NodeMessage) GetExecuteResponse() *NodeExecuteResponse
func (*NodeMessage) GetGetVarRequest ¶
func (x *NodeMessage) GetGetVarRequest() *GetVarRequest
func (*NodeMessage) GetGetVarResponse ¶
func (x *NodeMessage) GetGetVarResponse() *GetVarResponse
func (*NodeMessage) GetLlmGenerateRequest ¶
func (x *NodeMessage) GetLlmGenerateRequest() *LLMGenerateRequest
func (*NodeMessage) GetLlmGenerateResponse ¶
func (x *NodeMessage) GetLlmGenerateResponse() *LLMGenerateResponse
func (*NodeMessage) GetMsg ¶
func (x *NodeMessage) GetMsg() isNodeMessage_Msg
func (*NodeMessage) GetSandboxExecRequest ¶
func (x *NodeMessage) GetSandboxExecRequest() *SandboxExecRequest
func (*NodeMessage) GetSandboxExecResponse ¶
func (x *NodeMessage) GetSandboxExecResponse() *SandboxExecResponse
func (*NodeMessage) GetSetVarRequest ¶
func (x *NodeMessage) GetSetVarRequest() *SetVarRequest
func (*NodeMessage) GetSignalRequest ¶
func (x *NodeMessage) GetSignalRequest() *SignalRequest
func (*NodeMessage) GetSignalResponse ¶
func (x *NodeMessage) GetSignalResponse() *SignalResponse
func (*NodeMessage) GetStreamEmitRequest ¶
func (x *NodeMessage) GetStreamEmitRequest() *StreamEmitRequest
func (*NodeMessage) GetToolExecuteRequest ¶
func (x *NodeMessage) GetToolExecuteRequest() *ToolExecuteRequest
func (*NodeMessage) GetToolExecuteResponse ¶
func (x *NodeMessage) GetToolExecuteResponse() *ToolExecuteResponse
func (*NodeMessage) ProtoMessage ¶
func (*NodeMessage) ProtoMessage()
func (*NodeMessage) ProtoReflect ¶
func (x *NodeMessage) ProtoReflect() protoreflect.Message
func (*NodeMessage) Reset ¶
func (x *NodeMessage) Reset()
func (*NodeMessage) String ¶
func (x *NodeMessage) String() string
type NodeMessage_ExecuteRequest ¶
type NodeMessage_ExecuteRequest struct {
ExecuteRequest *NodeExecuteRequest `protobuf:"bytes,1,opt,name=execute_request,json=executeRequest,proto3,oneof"`
}
type NodeMessage_ExecuteResponse ¶
type NodeMessage_ExecuteResponse struct {
ExecuteResponse *NodeExecuteResponse `protobuf:"bytes,2,opt,name=execute_response,json=executeResponse,proto3,oneof"`
}
type NodeMessage_GetVarRequest ¶
type NodeMessage_GetVarRequest struct {
GetVarRequest *GetVarRequest `protobuf:"bytes,3,opt,name=get_var_request,json=getVarRequest,proto3,oneof"`
}
type NodeMessage_GetVarResponse ¶
type NodeMessage_GetVarResponse struct {
GetVarResponse *GetVarResponse `protobuf:"bytes,4,opt,name=get_var_response,json=getVarResponse,proto3,oneof"`
}
type NodeMessage_LlmGenerateRequest ¶
type NodeMessage_LlmGenerateRequest struct {
LlmGenerateRequest *LLMGenerateRequest `protobuf:"bytes,6,opt,name=llm_generate_request,json=llmGenerateRequest,proto3,oneof"`
}
type NodeMessage_LlmGenerateResponse ¶
type NodeMessage_LlmGenerateResponse struct {
LlmGenerateResponse *LLMGenerateResponse `protobuf:"bytes,7,opt,name=llm_generate_response,json=llmGenerateResponse,proto3,oneof"`
}
type NodeMessage_SandboxExecRequest ¶
type NodeMessage_SandboxExecRequest struct {
SandboxExecRequest *SandboxExecRequest `protobuf:"bytes,11,opt,name=sandbox_exec_request,json=sandboxExecRequest,proto3,oneof"`
}
type NodeMessage_SandboxExecResponse ¶
type NodeMessage_SandboxExecResponse struct {
SandboxExecResponse *SandboxExecResponse `protobuf:"bytes,12,opt,name=sandbox_exec_response,json=sandboxExecResponse,proto3,oneof"`
}
type NodeMessage_SetVarRequest ¶
type NodeMessage_SetVarRequest struct {
SetVarRequest *SetVarRequest `protobuf:"bytes,5,opt,name=set_var_request,json=setVarRequest,proto3,oneof"`
}
type NodeMessage_SignalRequest ¶
type NodeMessage_SignalRequest struct {
SignalRequest *SignalRequest `protobuf:"bytes,13,opt,name=signal_request,json=signalRequest,proto3,oneof"`
}
type NodeMessage_SignalResponse ¶
type NodeMessage_SignalResponse struct {
SignalResponse *SignalResponse `protobuf:"bytes,14,opt,name=signal_response,json=signalResponse,proto3,oneof"`
}
type NodeMessage_StreamEmitRequest ¶
type NodeMessage_StreamEmitRequest struct {
StreamEmitRequest *StreamEmitRequest `protobuf:"bytes,10,opt,name=stream_emit_request,json=streamEmitRequest,proto3,oneof"`
}
type NodeMessage_ToolExecuteRequest ¶
type NodeMessage_ToolExecuteRequest struct {
ToolExecuteRequest *ToolExecuteRequest `protobuf:"bytes,8,opt,name=tool_execute_request,json=toolExecuteRequest,proto3,oneof"`
}
type NodeMessage_ToolExecuteResponse ¶
type NodeMessage_ToolExecuteResponse struct {
ToolExecuteResponse *ToolExecuteResponse `protobuf:"bytes,9,opt,name=tool_execute_response,json=toolExecuteResponse,proto3,oneof"`
}
type NodeServiceClient ¶
type NodeServiceClient interface {
ListNodes(ctx context.Context, in *ListNodesRequest, opts ...grpc.CallOption) (*ListNodesResponse, error)
Execute(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[NodeMessage, NodeMessage], error)
}
NodeServiceClient is the client API for NodeService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
NodeService exposes node execution with bidirectional callbacks.
func NewNodeServiceClient ¶
func NewNodeServiceClient(cc grpc.ClientConnInterface) NodeServiceClient
type NodeServiceServer ¶
type NodeServiceServer interface {
ListNodes(context.Context, *ListNodesRequest) (*ListNodesResponse, error)
Execute(grpc.BidiStreamingServer[NodeMessage, NodeMessage]) error
// contains filtered or unexported methods
}
NodeServiceServer is the server API for NodeService service. All implementations must embed UnimplementedNodeServiceServer for forward compatibility.
NodeService exposes node execution with bidirectional callbacks.
type NodeService_ExecuteClient ¶
type NodeService_ExecuteClient = grpc.BidiStreamingClient[NodeMessage, NodeMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type NodeService_ExecuteServer ¶
type NodeService_ExecuteServer = grpc.BidiStreamingServer[NodeMessage, NodeMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type NodeSpec ¶
type NodeSpec struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
SchemaJson string `protobuf:"bytes,2,opt,name=schema_json,json=schemaJson,proto3" json:"schema_json,omitempty"`
// contains filtered or unexported fields
}
func (*NodeSpec) Descriptor
deprecated
func (*NodeSpec) GetSchemaJson ¶
func (*NodeSpec) ProtoMessage ¶
func (*NodeSpec) ProtoMessage()
func (*NodeSpec) ProtoReflect ¶
func (x *NodeSpec) ProtoReflect() protoreflect.Message
type PluginInfo ¶
type PluginInfo struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Version string `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
Type string `protobuf:"bytes,4,opt,name=type,proto3" json:"type,omitempty"`
Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
Author string `protobuf:"bytes,6,opt,name=author,proto3" json:"author,omitempty"`
Builtin bool `protobuf:"varint,7,opt,name=builtin,proto3" json:"builtin,omitempty"`
// contains filtered or unexported fields
}
func (*PluginInfo) Descriptor
deprecated
func (*PluginInfo) Descriptor() ([]byte, []int)
Deprecated: Use PluginInfo.ProtoReflect.Descriptor instead.
func (*PluginInfo) GetAuthor ¶
func (x *PluginInfo) GetAuthor() string
func (*PluginInfo) GetBuiltin ¶
func (x *PluginInfo) GetBuiltin() bool
func (*PluginInfo) GetDescription ¶
func (x *PluginInfo) GetDescription() string
func (*PluginInfo) GetId ¶
func (x *PluginInfo) GetId() string
func (*PluginInfo) GetName ¶
func (x *PluginInfo) GetName() string
func (*PluginInfo) GetType ¶
func (x *PluginInfo) GetType() string
func (*PluginInfo) GetVersion ¶
func (x *PluginInfo) GetVersion() string
func (*PluginInfo) ProtoMessage ¶
func (*PluginInfo) ProtoMessage()
func (*PluginInfo) ProtoReflect ¶
func (x *PluginInfo) ProtoReflect() protoreflect.Message
func (*PluginInfo) Reset ¶
func (x *PluginInfo) Reset()
func (*PluginInfo) String ¶
func (x *PluginInfo) String() string
type PluginLifecycleClient ¶
type PluginLifecycleClient interface {
Handshake(ctx context.Context, in *HandshakeRequest, opts ...grpc.CallOption) (*HandshakeResponse, error)
Initialize(ctx context.Context, in *InitializeRequest, opts ...grpc.CallOption) (*InitializeResponse, error)
Shutdown(ctx context.Context, in *ShutdownRequest, opts ...grpc.CallOption) (*ShutdownResponse, error)
HealthCheck(ctx context.Context, in *HealthCheckRequest, opts ...grpc.CallOption) (*HealthCheckResponse, error)
}
PluginLifecycleClient is the client API for PluginLifecycle service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
PluginLifecycle manages the external plugin lifecycle.
func NewPluginLifecycleClient ¶
func NewPluginLifecycleClient(cc grpc.ClientConnInterface) PluginLifecycleClient
type PluginLifecycleServer ¶
type PluginLifecycleServer interface {
Handshake(context.Context, *HandshakeRequest) (*HandshakeResponse, error)
Initialize(context.Context, *InitializeRequest) (*InitializeResponse, error)
Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
HealthCheck(context.Context, *HealthCheckRequest) (*HealthCheckResponse, error)
// contains filtered or unexported methods
}
PluginLifecycleServer is the server API for PluginLifecycle service. All implementations must embed UnimplementedPluginLifecycleServer for forward compatibility.
PluginLifecycle manages the external plugin lifecycle.
type SandboxExecRequest ¶
type SandboxExecRequest struct {
Command string `protobuf:"bytes,1,opt,name=command,proto3" json:"command,omitempty"`
// contains filtered or unexported fields
}
func (*SandboxExecRequest) Descriptor
deprecated
func (*SandboxExecRequest) Descriptor() ([]byte, []int)
Deprecated: Use SandboxExecRequest.ProtoReflect.Descriptor instead.
func (*SandboxExecRequest) GetCommand ¶
func (x *SandboxExecRequest) GetCommand() string
func (*SandboxExecRequest) ProtoMessage ¶
func (*SandboxExecRequest) ProtoMessage()
func (*SandboxExecRequest) ProtoReflect ¶
func (x *SandboxExecRequest) ProtoReflect() protoreflect.Message
func (*SandboxExecRequest) Reset ¶
func (x *SandboxExecRequest) Reset()
func (*SandboxExecRequest) String ¶
func (x *SandboxExecRequest) String() string
type SandboxExecResponse ¶
type SandboxExecResponse struct {
Output string `protobuf:"bytes,1,opt,name=output,proto3" json:"output,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*SandboxExecResponse) Descriptor
deprecated
func (*SandboxExecResponse) Descriptor() ([]byte, []int)
Deprecated: Use SandboxExecResponse.ProtoReflect.Descriptor instead.
func (*SandboxExecResponse) GetError ¶
func (x *SandboxExecResponse) GetError() string
func (*SandboxExecResponse) GetOutput ¶
func (x *SandboxExecResponse) GetOutput() string
func (*SandboxExecResponse) ProtoMessage ¶
func (*SandboxExecResponse) ProtoMessage()
func (*SandboxExecResponse) ProtoReflect ¶
func (x *SandboxExecResponse) ProtoReflect() protoreflect.Message
func (*SandboxExecResponse) Reset ¶
func (x *SandboxExecResponse) Reset()
func (*SandboxExecResponse) String ¶
func (x *SandboxExecResponse) String() string
type SetVarRequest ¶
type SetVarRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*SetVarRequest) Descriptor
deprecated
func (*SetVarRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetVarRequest.ProtoReflect.Descriptor instead.
func (*SetVarRequest) GetKey ¶
func (x *SetVarRequest) GetKey() string
func (*SetVarRequest) GetValue ¶
func (x *SetVarRequest) GetValue() string
func (*SetVarRequest) ProtoMessage ¶
func (*SetVarRequest) ProtoMessage()
func (*SetVarRequest) ProtoReflect ¶
func (x *SetVarRequest) ProtoReflect() protoreflect.Message
func (*SetVarRequest) Reset ¶
func (x *SetVarRequest) Reset()
func (*SetVarRequest) String ¶
func (x *SetVarRequest) String() string
type ShutdownRequest ¶
type ShutdownRequest struct {
// contains filtered or unexported fields
}
func (*ShutdownRequest) Descriptor
deprecated
func (*ShutdownRequest) Descriptor() ([]byte, []int)
Deprecated: Use ShutdownRequest.ProtoReflect.Descriptor instead.
func (*ShutdownRequest) ProtoMessage ¶
func (*ShutdownRequest) ProtoMessage()
func (*ShutdownRequest) ProtoReflect ¶
func (x *ShutdownRequest) ProtoReflect() protoreflect.Message
func (*ShutdownRequest) Reset ¶
func (x *ShutdownRequest) Reset()
func (*ShutdownRequest) String ¶
func (x *ShutdownRequest) String() string
type ShutdownResponse ¶
type ShutdownResponse struct {
// contains filtered or unexported fields
}
func (*ShutdownResponse) Descriptor
deprecated
func (*ShutdownResponse) Descriptor() ([]byte, []int)
Deprecated: Use ShutdownResponse.ProtoReflect.Descriptor instead.
func (*ShutdownResponse) ProtoMessage ¶
func (*ShutdownResponse) ProtoMessage()
func (*ShutdownResponse) ProtoReflect ¶
func (x *ShutdownResponse) ProtoReflect() protoreflect.Message
func (*ShutdownResponse) Reset ¶
func (x *ShutdownResponse) Reset()
func (*ShutdownResponse) String ¶
func (x *ShutdownResponse) String() string
type SignalRequest ¶
type SignalRequest struct {
SignalType string `protobuf:"bytes,1,opt,name=signal_type,json=signalType,proto3" json:"signal_type,omitempty"`
Payload []byte `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
// contains filtered or unexported fields
}
func (*SignalRequest) Descriptor
deprecated
func (*SignalRequest) Descriptor() ([]byte, []int)
Deprecated: Use SignalRequest.ProtoReflect.Descriptor instead.
func (*SignalRequest) GetPayload ¶
func (x *SignalRequest) GetPayload() []byte
func (*SignalRequest) GetSignalType ¶
func (x *SignalRequest) GetSignalType() string
func (*SignalRequest) ProtoMessage ¶
func (*SignalRequest) ProtoMessage()
func (*SignalRequest) ProtoReflect ¶
func (x *SignalRequest) ProtoReflect() protoreflect.Message
func (*SignalRequest) Reset ¶
func (x *SignalRequest) Reset()
func (*SignalRequest) String ¶
func (x *SignalRequest) String() string
type SignalResponse ¶
type SignalResponse struct {
Error string `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*SignalResponse) Descriptor
deprecated
func (*SignalResponse) Descriptor() ([]byte, []int)
Deprecated: Use SignalResponse.ProtoReflect.Descriptor instead.
func (*SignalResponse) GetError ¶
func (x *SignalResponse) GetError() string
func (*SignalResponse) ProtoMessage ¶
func (*SignalResponse) ProtoMessage()
func (*SignalResponse) ProtoReflect ¶
func (x *SignalResponse) ProtoReflect() protoreflect.Message
func (*SignalResponse) Reset ¶
func (x *SignalResponse) Reset()
func (*SignalResponse) String ¶
func (x *SignalResponse) String() string
type StreamEmitRequest ¶
type StreamEmitRequest struct {
Data string `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*StreamEmitRequest) Descriptor
deprecated
func (*StreamEmitRequest) Descriptor() ([]byte, []int)
Deprecated: Use StreamEmitRequest.ProtoReflect.Descriptor instead.
func (*StreamEmitRequest) GetData ¶
func (x *StreamEmitRequest) GetData() string
func (*StreamEmitRequest) ProtoMessage ¶
func (*StreamEmitRequest) ProtoMessage()
func (*StreamEmitRequest) ProtoReflect ¶
func (x *StreamEmitRequest) ProtoReflect() protoreflect.Message
func (*StreamEmitRequest) Reset ¶
func (x *StreamEmitRequest) Reset()
func (*StreamEmitRequest) String ¶
func (x *StreamEmitRequest) String() string
type ToolExecuteRequest ¶
type ToolExecuteRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Arguments string `protobuf:"bytes,2,opt,name=arguments,proto3" json:"arguments,omitempty"`
// contains filtered or unexported fields
}
func (*ToolExecuteRequest) Descriptor
deprecated
func (*ToolExecuteRequest) Descriptor() ([]byte, []int)
Deprecated: Use ToolExecuteRequest.ProtoReflect.Descriptor instead.
func (*ToolExecuteRequest) GetArguments ¶
func (x *ToolExecuteRequest) GetArguments() string
func (*ToolExecuteRequest) GetName ¶
func (x *ToolExecuteRequest) GetName() string
func (*ToolExecuteRequest) ProtoMessage ¶
func (*ToolExecuteRequest) ProtoMessage()
func (*ToolExecuteRequest) ProtoReflect ¶
func (x *ToolExecuteRequest) ProtoReflect() protoreflect.Message
func (*ToolExecuteRequest) Reset ¶
func (x *ToolExecuteRequest) Reset()
func (*ToolExecuteRequest) String ¶
func (x *ToolExecuteRequest) String() string
type ToolExecuteResponse ¶
type ToolExecuteResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*ToolExecuteResponse) Descriptor
deprecated
func (*ToolExecuteResponse) Descriptor() ([]byte, []int)
Deprecated: Use ToolExecuteResponse.ProtoReflect.Descriptor instead.
func (*ToolExecuteResponse) GetError ¶
func (x *ToolExecuteResponse) GetError() string
func (*ToolExecuteResponse) GetResult ¶
func (x *ToolExecuteResponse) GetResult() string
func (*ToolExecuteResponse) ProtoMessage ¶
func (*ToolExecuteResponse) ProtoMessage()
func (*ToolExecuteResponse) ProtoReflect ¶
func (x *ToolExecuteResponse) ProtoReflect() protoreflect.Message
func (*ToolExecuteResponse) Reset ¶
func (x *ToolExecuteResponse) Reset()
func (*ToolExecuteResponse) String ¶
func (x *ToolExecuteResponse) String() string
type ToolServiceClient ¶
type ToolServiceClient interface {
ListTools(ctx context.Context, in *ListToolsRequest, opts ...grpc.CallOption) (*ListToolsResponse, error)
Execute(ctx context.Context, in *ToolExecuteRequest, opts ...grpc.CallOption) (*ToolExecuteResponse, error)
}
ToolServiceClient is the client API for ToolService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
ToolService exposes tool execution from external plugins.
func NewToolServiceClient ¶
func NewToolServiceClient(cc grpc.ClientConnInterface) ToolServiceClient
type ToolServiceServer ¶
type ToolServiceServer interface {
ListTools(context.Context, *ListToolsRequest) (*ListToolsResponse, error)
Execute(context.Context, *ToolExecuteRequest) (*ToolExecuteResponse, error)
// contains filtered or unexported methods
}
ToolServiceServer is the server API for ToolService service. All implementations must embed UnimplementedToolServiceServer for forward compatibility.
ToolService exposes tool execution from external plugins.
type ToolSpec ¶
type ToolSpec struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
InputSchemaJson string `protobuf:"bytes,3,opt,name=input_schema_json,json=inputSchemaJson,proto3" json:"input_schema_json,omitempty"`
// contains filtered or unexported fields
}
func (*ToolSpec) Descriptor
deprecated
func (*ToolSpec) GetDescription ¶
func (*ToolSpec) GetInputSchemaJson ¶
func (*ToolSpec) ProtoMessage ¶
func (*ToolSpec) ProtoMessage()
func (*ToolSpec) ProtoReflect ¶
func (x *ToolSpec) ProtoReflect() protoreflect.Message
type UnimplementedNodeServiceServer ¶
type UnimplementedNodeServiceServer struct{}
UnimplementedNodeServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedNodeServiceServer) Execute ¶
func (UnimplementedNodeServiceServer) Execute(grpc.BidiStreamingServer[NodeMessage, NodeMessage]) error
func (UnimplementedNodeServiceServer) ListNodes ¶
func (UnimplementedNodeServiceServer) ListNodes(context.Context, *ListNodesRequest) (*ListNodesResponse, error)
type UnimplementedPluginLifecycleServer ¶
type UnimplementedPluginLifecycleServer struct{}
UnimplementedPluginLifecycleServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPluginLifecycleServer) Handshake ¶
func (UnimplementedPluginLifecycleServer) Handshake(context.Context, *HandshakeRequest) (*HandshakeResponse, error)
func (UnimplementedPluginLifecycleServer) HealthCheck ¶
func (UnimplementedPluginLifecycleServer) HealthCheck(context.Context, *HealthCheckRequest) (*HealthCheckResponse, error)
func (UnimplementedPluginLifecycleServer) Initialize ¶
func (UnimplementedPluginLifecycleServer) Initialize(context.Context, *InitializeRequest) (*InitializeResponse, error)
func (UnimplementedPluginLifecycleServer) Shutdown ¶
func (UnimplementedPluginLifecycleServer) Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
type UnimplementedToolServiceServer ¶
type UnimplementedToolServiceServer struct{}
UnimplementedToolServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedToolServiceServer) Execute ¶
func (UnimplementedToolServiceServer) Execute(context.Context, *ToolExecuteRequest) (*ToolExecuteResponse, error)
func (UnimplementedToolServiceServer) ListTools ¶
func (UnimplementedToolServiceServer) ListTools(context.Context, *ListToolsRequest) (*ListToolsResponse, error)
type UnsafeNodeServiceServer ¶
type UnsafeNodeServiceServer interface {
// contains filtered or unexported methods
}
UnsafeNodeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NodeServiceServer will result in compilation errors.
type UnsafePluginLifecycleServer ¶
type UnsafePluginLifecycleServer interface {
// contains filtered or unexported methods
}
UnsafePluginLifecycleServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PluginLifecycleServer will result in compilation errors.
type UnsafeToolServiceServer ¶
type UnsafeToolServiceServer interface {
// contains filtered or unexported methods
}
UnsafeToolServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ToolServiceServer will result in compilation errors.